###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.0 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder
import Products
import base_item

import category

manage_addNewsFolderForm = HTMLFile('newsfolderAdd', globals())

def manage_addNewsFolder(self, title, description, REQUEST=None, RESPONSE=None):
	"Add an instance of the NewsFolder class"

	id = str(self.get_id())

	self._setObject(id, NewsFolder(id, title, description))

	if RESPONSE and REQUEST:

		RESPONSE.redirect(REQUEST['URL3'])


class NewsFolder(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"Documentation string"

	meta_type = 'NewsFolder'
	icon = 'misc_/NewsFolder/Folder_icon.gif'
	default_catalog = 'Catalog'

	_properties = (
		{'id':'title', 'type':'string'},
		{'id':'description', 'type':'text'},
		)

	meta_types = (
		{'name':'Category', 'action':'manage_addCategoryForm'},
		)

	manage_addCategoryForm = category.manage_addCategoryForm
	manage_addCategory = category.manage_addCategory
	categoryAdd2 = category.categoryAdd2

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('Add Category',
		 ('manage_addCategory', 'manage_addCategoryForm')),
		('View NewsFolders',
		 ('',)),
		)

	index_html = HTMLFile('newsfolderIndex', globals())
	display = HTMLFile('news_folder_display', globals())

	base_edit = HTMLFile('news_folder_edit', globals())

	product_name = 'NewsFolder'

	def __init__(self, id, title='', description=''):
		"Initialize the class instance"

		self.id = id
		self.title = title
		self.description = description
		self.index_object()

		self.manage_addCategory('Internal', 'Internal', 'This category contains internal news', public=0)
		self.manage_addCategory('Public', 'Public', 'This container contains public news', public=1)


	def sequence_color(self, context=None):
		"""Renders the appropriate color."""

		if not context:

			raise

	def get_news(self, number_of_news_items=10):
		"""Returns all news messages, sorted by date submitted."""

		news_items = []

		for category in self.objectValues('Category'):

			map(news_items.append, category.get_news())

		news_items.sort(
			lambda x,y: cmp(
			x.bobobase_modification_time, y.bobobase_modification_time
			))

		if number_of_news_items:

			return news_items[:number_of_news_items]

		else:

			return news_items


default__class_init__(NewsFolder)

